summaryrefslogtreecommitdiffstats
path: root/kmail/vacation.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/vacation.cpp')
-rw-r--r--kmail/vacation.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kmail/vacation.cpp b/kmail/vacation.cpp
index 0b9222f4..e706243c 100644
--- a/kmail/vacation.cpp
+++ b/kmail/vacation.cpp
@@ -212,7 +212,7 @@ namespace {
static const GenericInformationExtractor::StateNode spamNodes[] = {
{ 0, GIE::CommandStart, "if", 1, 0, 0 }, // 0
{ 0, GIE::TestStart, "header", 2, 0, 0 }, // 1
- { 0, GIE::TaggedArgument, "contains", 3, 0, 0 }, // 2
+ { 0, GIE::TaggedArgument, "tqcontains", 3, 0, 0 }, // 2
// accept both string and string-list:
{ 0, GIE::StringArgument, "x-spam-flag", 9, 4, "x-spam-flag" }, // 3
@@ -259,16 +259,16 @@ namespace {
// to understand this table, study the output of
// libksieve/tests/parsertest
// 'if not address :domain :contains ["from"] ["mydomain.org"] { keep; stop; }'
static const GenericInformationExtractor::StateNode domainNodes[] = {
{ 0, GIE::CommandStart, "if", 1, 0, 0 }, // 0
{ 0, GIE::TestStart, "not", 2, 0, 0, }, // 1
{ 0, GIE::TestStart, "address", 3, 0, 0 }, // 2
// :domain and :contains in arbitrary order:
{ 0, GIE::TaggedArgument, "domain", 4, 5, 0 }, // 3
- { 0, GIE::TaggedArgument, "contains", 7, 0, 0 }, // 4
- { 0, GIE::TaggedArgument, "contains", 6, 0, 0 }, // 5
+ { 0, GIE::TaggedArgument, "tqcontains", 7, 0, 0 }, // 4
+ { 0, GIE::TaggedArgument, "tqcontains", 6, 0, 0 }, // 5
{ 0, GIE::TaggedArgument, "domain", 7, 0, 0 }, // 6
// accept both string and string-list:
@@ -448,9 +448,9 @@ namespace KMail {
static inline TQString dotstuff( TQString s ) {
if ( s.startsWith( "." ) )
- return '.' + s.replace( "\n.", "\n.." );
+ return '.' + s.tqreplace( "\n.", "\n.." );
else
- return s.replace( "\n.", "\n.." );
+ return s.tqreplace( "\n.", "\n.." );
}
TQString Vacation::composeScript( const TQString & messageText,
@@ -464,26 +464,26 @@ namespace KMail {
addressesArgument += ":addresses [ ";
TQStringList sl;
for ( AddrSpecList::const_iterator it = addrSpecs.begin() ; it != addrSpecs.end() ; ++it ) {
- sl.push_back( '"' + (*it).asString().replace( '\\', "\\\\" ).replace( '"', "\\\"" ) + '"' );
+ sl.push_back( '"' + (*it).asString().tqreplace( '\\', "\\\\" ).tqreplace( '"', "\\\"" ) + '"' );
aliases.push_back( (*it).asString() );
}
addressesArgument += sl.join( ", " ) + " ] ";
}
- TQString script = TQString::fromLatin1("require \"vacation\";\n\n" );
+ TQString script = TQString::tqfromLatin1("require \"vacation\";\n\n" );
if ( !sendForSpam )
- script += TQString::fromLatin1( "if header :contains \"X-Spam-Flag\" \"YES\""
+ script += TQString::tqfromLatin1( "if header :tqcontains \"X-Spam-Flag\" \"YES\""
" { keep; stop; }\n" ); // FIXME?
if ( !domain.isEmpty() ) // FIXME
- script += TQString::fromLatin1( "if not address :domain :contains \"from\" \"%1\" { keep; stop; }\n" ).arg( domain );
+ script += TQString::tqfromLatin1( "if not address :domain :tqcontains \"from\" \"%1\" { keep; stop; }\n" ).arg( domain );
script += "vacation ";
script += addressesArgument;
if ( notificationInterval > 0 )
- script += TQString::fromLatin1(":days %1 ").arg( notificationInterval );
- script += TQString::fromLatin1("text:\n");
+ script += TQString::tqfromLatin1(":days %1 ").arg( notificationInterval );
+ script += TQString::tqfromLatin1("text:\n");
script += dotstuff( messageText.isEmpty() ? defaultMessageText() : messageText );
- script += TQString::fromLatin1( "\n.\n;\n" );
+ script += TQString::tqfromLatin1( "\n.\n;\n" );
return script;
}
@@ -565,15 +565,15 @@ namespace KMail {
TQString Vacation::defaultMessageText() {
return i18n("I am out of office till %1.\n"
"\n"
- "In urgent cases, please contact Mrs. <vacation replacement>\n"
+ "In urgent cases, please contact Mrs. <vacation tqreplacement>\n"
"\n"
- "email: <email address of vacation replacement>\n"
+ "email: <email address of vacation tqreplacement>\n"
"phone: +49 711 1111 11\n"
"fax.: +49 711 1111 12\n"
"\n"
"Yours sincerely,\n"
"-- <enter your name and email address here>\n")
- .arg( KGlobal::locale()->formatDate( TQDate::currentDate().addDays( 1 ) ) );
+ .arg( KGlobal::locale()->formatDate( TQDate::tqcurrentDate().addDays( 1 ) ) );
}
int Vacation::defaultNotificationInterval() {
@@ -608,7 +608,7 @@ namespace KMail {
mSieveJob = 0; // job deletes itself after returning from this slot!
if ( !mCheckOnly && mUrl.protocol() == "sieve" && !job->sieveCapabilities().isEmpty() &&
- !job->sieveCapabilities().contains("vacation") ) {
+ !job->sieveCapabilities().tqcontains("vacation") ) {
KMessageBox::sorry( 0, i18n("Your server did not list \"vacation\" in "
"its list of supported Sieve extensions;\n"
"without it, KMail cannot install out-of-"
@@ -259,16 +259,16 @@ namespace {
// to understand this table, study the output of
// libksieve/tests/parsertest
- // 'if not address :domain :contains ["from"] ["mydomain.org"] { keep; stop; }'
+ // 'if not address :domain :tqcontains ["from"] ["mydomain.org"] { keep; stop; }'
static const GenericInformationExtractor::StateNode domainNodes[] = {
{ 0, GIE::CommandStart, "if", 1, 0, 0 }, // 0
@@ -259,16 +259,16 @@ namespace {
{ 0, GIE::TestStart, "not", 2, 0, 0, }, // 1
{ 0, GIE::TestStart, "address", 3, 0, 0 }, // 2
- // :domain and :contains in arbitrary order:
+ // :domain and :tqcontains in arbitrary order:
{ 0, GIE::TaggedArgument, "domain", 4, 5, 0 }, // 3